@@ -1,6 +1,10 @@
 # -*- coding: utf-8 -*-
 
 """
+C2 DATA VIEWER is distributed subject to a Software License Agreement found
+in the file LICENSE that is included with this distribution.
+SPDX-License-Identifier: EPICS
+
 Copyright 2018 UChicago Argonne LLC
  as operator of Argonne National Laboratory
 
@@ -10,9 +14,10 @@ PVA object viewer utilities
 """
 import datetime
 from pyqtgraph import Qt
-import pyqtgraph.ptime as ptime
+import time
 from pyqtgraph.functions import mkPen
 from pyqtgraph import PlotWidget
+from PyQt5 import QtWidgets
 
 from ..view.image_definitions import COLOR_MODE_MONO, COLOR_MODES
 from ..model import ConnectionState
@@ -24,6 +29,9 @@ class ImageController:
     SPINNER_MAX_VAL = 1.7976931348623157e+308
     SPINNER_MIN_VAL = -SPINNER_MAX_VAL
 
+    HIDE_CONTROL_TEXT = 'Hide Control Panel'
+    SHOW_CONTROL_TEXT = 'Show Control Panel'
+
     def __init__(self, widget, **kargs):
         """
 
@@ -164,7 +172,30 @@ class ImageController:
 
         self.frameRateChanged()
         self.camera_changed()
-        
+
+        self._imageContextMenu = QtWidgets.QMenu(self._win.imageWidget)
+        self._imageContextMenuAction = QtWidgets.QAction(self.HIDE_CONTROL_TEXT, self._win.imageWidget)
+        self._imageContextMenu.addAction(self._imageContextMenuAction)
+        self._win.imageWidget.customContextMenuRequested.connect(self.on_context_menu)
+        self._scrollAreaWidth = 0
+
+    def on_context_menu(self, point):
+        # show context menu
+        action = self._imageContextMenu.exec_(self._win.imageWidget.mapToGlobal(point))
+        if not action:
+            return
+        if action.text() == self.HIDE_CONTROL_TEXT:
+            action.setText(self.SHOW_CONTROL_TEXT)
+            self._win.scrollArea.hide()
+            self._scrollAreaWidth = self._win.scrollArea.parent().minimumWidth()
+            self._win.scrollArea.parent().setMinimumWidth(0)
+            self._win.scrollArea.parent().setMinimumHeight(0)
+        else:
+            action.setText(self.HIDE_CONTROL_TEXT)
+            self._win.scrollArea.show()
+            self._win.scrollArea.parent().setMinimumWidth(self._scrollAreaWidth)
+        self._win.imageWidget.adjustSize()
+
     def _callback_black_changed_slider(self):
         """
         This callback is called when user change the value on the "black" slider.
@@ -410,6 +441,8 @@ class ImageController:
         lolimit = kargs.get('lowlimit', None)
         callback = kargs.get('callback', False)
 
+        if type(value) is list:
+            value = value[0]
         if roi_value is not None:
             fmt = f"{fmt} ({fmt})"
             if type(value) is tuple:
@@ -452,7 +485,7 @@ class ImageController:
         """
 
         # Get current time
-        now = ptime.time()
+        now = time.time()
 
         # Set required variabels on first call
         if self._last_time_stat_calculated is None:
@@ -533,7 +566,7 @@ class ImageController:
         """
         self._last_time_stat_calculated = None
         self._win.imageWidget.__last_array_id = None
-        self._start_time = ptime.time()
+        self._start_time = time.time()
         self.runtime = 0
         self._win.imageWidget.MB_received = 0.0
         self._win.imageWidget.frames_received = 0
@@ -688,8 +721,8 @@ class ImageController:
                                self.SLIDER_MAX_VAL / maxVal if maxVal != 0 else 0,)
 
         self._imageBlackSliderFactor = sliderFactor
-        self._win.imageBlackSlider.setMinimum(minVal * sliderFactor)
-        self._win.imageBlackSlider.setMaximum(maxVal * sliderFactor)
+        self._win.imageBlackSlider.setMinimum(int(minVal * sliderFactor))
+        self._win.imageBlackSlider.setMaximum(int(maxVal * sliderFactor))
 
         self._win.imageBlackSpinBox.setMinimum(minVal)
         self._win.imageBlackSpinBox.setMaximum(maxVal)
@@ -719,8 +752,8 @@ class ImageController:
                                self.SLIDER_MAX_VAL / maxVal if maxVal != 0 else 0,)
 
         self._imageWhiteSliderFactor = sliderFactor
-        self._win.imageWhiteSlider.setMinimum(minVal * sliderFactor)
-        self._win.imageWhiteSlider.setMaximum(maxVal * sliderFactor)
+        self._win.imageWhiteSlider.setMinimum(int(minVal * sliderFactor))
+        self._win.imageWhiteSlider.setMaximum(int(maxVal * sliderFactor))
 
         self._win.imageWhiteSpinBox.setMinimum(minVal)
         self._win.imageWhiteSpinBox.setMaximum(maxVal)
@@ -747,7 +780,7 @@ class ImageController:
         self._win.imageBlackSpinBox.blockSignals(False)
 
         self._win.imageBlackSlider.blockSignals(True)
-        self._win.imageBlackSlider.setValue(value * self._imageBlackSliderFactor)
+        self._win.imageBlackSlider.setValue(int(value * self._imageBlackSliderFactor))
         self._win.imageBlackSlider.blockSignals(False)
 
     def updateGuiWhite(self, value):
@@ -764,5 +797,5 @@ class ImageController:
 
         # Update the slider
         self._win.imageWhiteSlider.blockSignals(True)
-        self._win.imageWhiteSlider.setValue(value * self._imageWhiteSliderFactor)
+        self._win.imageWhiteSlider.setValue(int(value * self._imageWhiteSliderFactor))
         self._win.imageWhiteSlider.blockSignals(False)
