@@ -1,6 +1,10 @@
 # -*- coding: utf-8 -*-
 
 """
+C2 DATA VIEWER is distributed subject to a Software License Agreement found
+in the file LICENSE that is included with this distribution.
+SPDX-License-Identifier: EPICS
+
 Copyright 2018 UChicago Argonne LLC
  as operator of Argonne National Laboratory
 
@@ -11,10 +15,10 @@ PVA object viewer utilities for image display
 from datetime import datetime
 import numpy as np
 import pyqtgraph
-import pyqtgraph.ptime as ptime
 from pyqtgraph.Qt import QtCore
 import enum
 import logging
+import time
 
 class PlotChannel:
     def __init__(self, pvname, color):
@@ -241,10 +245,10 @@ class Trigger:
         except Exception:
             pass
     
-class PlotWidget(pyqtgraph.GraphicsWindow):
+class PlotWidget(pyqtgraph.GraphicsLayoutWidget):
 
     def __init__(self, parent=None, **kargs):
-        pyqtgraph.GraphicsWindow.__init__(self, parent=parent)
+        pyqtgraph.GraphicsLayoutWidget.__init__(self, parent=parent)
         self.setParent(parent)
 
         self.param_changed = False
@@ -282,7 +286,7 @@ class PlotWidget(pyqtgraph.GraphicsWindow):
         self.minor_ticks = 0
         
         self.fps = 0
-        self.lastTime = ptime.time()
+        self.lastTime = time.time()
 
         self._max = None
         self._min = None
@@ -469,6 +473,11 @@ class PlotWidget(pyqtgraph.GraphicsWindow):
         :names: (list -> strings) List of channels to bi displayed. "None" should be used to ignore that channel.
         :return: (None)
         """
+        # Workaround until pyqtgraph issue with multiple axis is resolved
+        # (see https://git.aps.anl.gov/C2/conda/data-viewer/-/issues/48)
+        # Pick up proper viewbox geometry from parent
+        self.ci.addItem(self.plot, row=2)
+
         # We do not use default axis
         self.plot.hideAxis('left')
 
@@ -1079,7 +1088,7 @@ class PlotWidget(pyqtgraph.GraphicsWindow):
 
         :return:
         """
-        now = ptime.time()
+        now = time.time()
         dt = now - self.lastTime
         self.lastTime = now
         if self.fps is None:
