@@ -1,6 +1,10 @@
 # -*- coding: utf-8 -*-
 
 """
+C2 DATA VIEWER is distributed subject to a Software License Agreement found
+in the file LICENSE that is included with this distribution.
+SPDX-License-Identifier: EPICS
+
 Copyright 2020 UChicago Argonne LLC
  as operator of Argonne National Laboratory
 
@@ -11,6 +15,7 @@ Helper functions for c2d unit tests.
 from datetime import datetime as dt
 import numpy as np
 import pvaccess as pva
+from pyqtgraph.Qt import QtWidgets
 
 from c2dataviewer.view.image_definitions import *
 from c2dataviewer.view.image_display import ImagePlotWidget
@@ -68,7 +73,6 @@ def create_image(id, image=None, data_type='ubyteValue', nx=None, ny=None, nz=No
             dims.insert(1, pva.PvDimension(nz, 0, nz, 1, False))
         elif color_mode == COLOR_MODE_RGB3:
             dims.append(pva.PvDimension(nz, 0, nz, 1, False))
-    nda['codec'] = pva.PvCodec('pvapyc', pva.PvInt(14))
     nda['dimension'] = dims
     nda['descriptor'] = 'PvaPy Simulated Image'
     nda['compressedSize'] = nx*ny*(nz if nz is not None else 1)
@@ -81,3 +85,13 @@ def create_image(id, image=None, data_type='ubyteValue', nx=None, ny=None, nz=No
     nda['value'] = {data_type : image}
 
     return nda
+
+app = None
+
+def setup_qt_app():
+    global app
+    
+    if not app:
+        app = QtWidgets.QApplication.instance()
+        if not app:
+            app  = QtWidgets.QApplication([])
